# Calculation method

- [Determination of cabin geometry](#cabin-geometry)
- [Determination of fuselage geometry](#fuselage-geometry)
- [Estimation of masses](#mass-estimation)
- [Generation of fuselage shape](#generate-shape)

!!! note 
    Currently the tool supports only one fuselage with one payload tube.

## Determine cabin geometry {#cabin-geometry}
### Cabin width
The cabin width is estimated using the given class definition.

#### Determine width of seat row per aircraft side
The width of one seat row/bench $w_{\text{bench}}$ (in inch) can be determined for the left and right side of the aircraft using the following equation:
$$
    w_{\text{bench}} = n_{\text{seats}} \cdot w_{\text{seat}} + 2 \cdot w_{\text{armrest}}
$$

In which

- $n_{\text{seats}}$ - number of seats per seat bench
- $w_{\text{seat}}$ - seat width (taken from lowest class seat)
- $w_{\text{armrest}}$ - armrest width (taken from lowest class seat)

#### Calculate cabin width
The cabin width $w_{\text{cabin}}$ (in inch) can then be calculated:
$$
    w_{\text{cabin}} = w_{\text{aisle}} + w_{\text{bench,left}} + w_{\text{bench,right}} + 2 \cdot w_{\text{seat space}}
$$

In which

- $w_{\text{aisle}}$ - passenger aisle width
- $w_{\text{seat space}}$ - lowest class seat space

In case of a **wide-body aircraft configuration** there is an additional row in the middle of the aircraft as well as an additional passenger aisle. The width of the seat bench $w_{\text{bench,center}}$ can be calculated using an equation similar to that in the previous section.
$$
    w_{\text{bench,center}} = n_{\text{seats}} \cdot w_{\text{seat}} + 2 \cdot w_{\text{armrest,outer}} + (n_{\text{seats}} - 1) \cdot w_{\text{armrest,inner}}
$$

In which

- $w_{\text{seat}}$ - seat width (from lowest class seat parameters of right side)
- $w_{\text{armrest,outer}}$ - width of outer armrest (from lowest class seat parameters of right side)
- $w_{\text{armrest,inner}}$ - width of inner armrest (from lowest class seat parameters of right side)

The equation for the cabin width estimation must be adapted accordingly:
$$
    w_{\text{cabin}} = w_{\text{aisle}} + w_{\text{bench,left}} + w_{\text{bench,right}} + 2 \cdot w_{\text{seat space}} + w_{\text{aisle}} + w_{\text{bench,center}}
$$

### Cabin slenderness ratio <sup>[1]</sup>
The cabin slenderness ratio describes the ratio of cabin width to cabin length and can be determined using the following equation:
$$
    \frac{w_{\text{cabin}}}{l_{\text{cabin}}} = \frac{n_{\text{PAX per class}}}{ab} \cdot \left[ sp + \frac{a_{\text{service}}}{w_{\text{seat}}} + \frac{a_{\text{bulk}}}{\frac{w_{\text{aisle}}}{ab} + w_{\text{seat}}} + x \cdot w_{\text{exit}} \cdot \left( \frac{ab}{n_{\text{PAX per class}}} + \frac{sp}{d_{\text{exits}}} \right)  \right]
$$

In which

- $x$ - factor (1 for single-aisle, 2 for wide-body)
- $n_{\text{PAX per class}}$ - number of PAX per class
- $ab$ - seat abreast
- $sp$ - seat pitch
- $a_{\text{service}}$ - service area per PAX
- $a_{\text{bulk}}$ - bulk area per PAX
- $w_{\text{exit}}$ - exit width
- $d_{\text{exits}}$ - maximum distance between two exits

### Cabin length
Knowing the cabin width and the cabin slenderness ratio, the cabin length (in inch) can be calculated:
$$
    l_{\text{cabin}} = \frac{w_{\text{cabin}}}{\frac{w_{\text{cabin}}}{l_{\text{cabin}}}}
$$

### Cabin wall thickness
The cabin wall thickness can be estimated using the following calculation:
$$
    t_{\text{wall}} = 0.02 \cdot w_{\text{cabin}} + 2.5"
$$

### Cabin floor thickness
With the use of the cabin wall thickness, the cabin floor thickness can be calculated:
$$
    t_{\text{floor}} = 1.5 \cdot t_{\text{wall}}
$$

## Determine fuselage geometry {#fuselage-geometry}
With the calculated cabin the fuselage dimensions can be estimated.

### Fuselage length<sup>[2]</sup>
The fuselage length can be determined via regression formulas using the cabin length (in meter).

For single-aisle aircraft:
$$
    l_{\text{fuselage}} = \frac{l_{\text{cabin}}}{0.23482756 \cdot \log l_{\text{cabin}} - 0.05106017}
$$

For wide-body aircraft:
$$
    l_{\text{fuselage}} = \frac{l_{\text{cabin}}}{0.1735 \cdot \log l_{\text{cabin}} - 0.0966}
$$

### Fuselage diameters
The fuselage does not necessarily have a circular cross-section. It is more common to design elliptical cross-sections. Because of that, there are several values that must be determined:

- Fuselage diameter in y-direction
- Fuselage diameter in negative z-direction
- Fuselage diameter in positive z-direction

#### Fuselage diameter in y-direction
The fuselage diameter in y-direction $d_{\text{fuselage,y}}$ can be calculated in the following way:
$$
    d_{\text{fuselage,y}} = w_{\text{cabin}} + 2 \cdot t_{\text{wall}}
$$

#### Fuselage diameter in negative z-direction
The fuselage diameter in negative z-direction $d_{\text{fuselage,z,neg}}$ is determined by the cargo accommodation. It can be calculated in the following way.

At first, the distance to the cargo bottom is calculated:
$$
    d_{\text{to cargo bottom}} = h_{\text{ULD,max}} + t_{\text{floor}} + d_{\text{container to ceil}} + o_{\text{cabin floor}}
$$

In which

- $h_{\text{ULD,max}}$ - maximum height of unit load device
- $t_{\text{floor}}$ - floor thickness
- $d_{\text{container to ceil}}$ - distance from the container to the ceiling
- $o_{\text{cabin floor}}$ - offset cabin floor

Afterwards, the distance to the lower compartment edge is estimated:
$$
    d_{\text{to lower compartment edge}} = d_{\text{container to wall}} + 0.5 \cdot w_{\text{base,max}}
$$
In which
- $d_{\text{container to wall}}$ - distance from container to wall
- $w_{\text{base,max}}$ - maximum width at container base

Based on the Pythagorean theorem, the inner fuselage diameter (that equals the hypotenuse) can be calculated:
$$
    d_{\text{fuselage,z,neg,inner}} = \sqrt{(d_{\text{to cargo bottom}})^2 + (d_{\text{to lower compartment edge}})^2}
$$

Adding the wall thickness results in the fuselage diameter in negative z-direction:
$$
    d_{\text{fuselage,z,neg}} = d_{\text{fuselage,z,neg,inner}} + t_{\text{wall}}
$$

#### Fuselage diameter in positive z-direction
The fuselage diameter in positive z-direction $d_{\text{fuselage,z,pos}}$ is determined by the passenger accommodation. It can be calculated in the following way.

Firstly, the inner fuselage height (equals outer cabin height) can be determined:
$$
    d_{\text{fuselage,z,pos,inner}} = h_{\text{aisle,standing}} - o_{\text{cabin floor}} + h_{\text{system bay}}
$$

In which

- $h_{\text{aisle,standing}}$ - passenger aisle standing height
- $o_{\text{cabin floor}}$ - cabin floor offset
- $h_{\text{system bay}}$ - system bay height above cabin

Adding the wall thickness leads to the fuselage diameter in positive z-direction.
$$
    d_{\text{fuselage,z,pos}} = d_{\text{fuselage,z,pos,inner}} + t_{\text{wall}}
$$

### Fuselage height
The total height of the fuselage can be determined by summing up the fuselage diameters in positive and negative z-direction:
$$
    h_{\text{fuselage}} = d_{\text{fuselage,z,pos}} + d_{\text{fuselage,z,neg}}
$$

!!! note 
    If the `force_circle_cross_section` mode is selected, fuselage height and width are set to the maximum of both.

## Mass estimation {#mass-estimation}
The following masses are estimated:

- Fuselage structure
- Operator items
- Furnishing

Please refer to _Synthesis of Subsonic Airplane Design_ by E. Torenbeek<sup>[3]</sup> and the Certification Specifications<sup>[4]</sup> for further information.

!!! note 
    All masses are estimated in accordance with the CPACS standard.
<!-- ## Estimate positions and COG -->

## Generate fuselage shape {#generate-shape}
The fuselage shape is generated using the calculated data and the reference ellipses (see the [getting started](getting_started.md) page for more information). The final geometry is written to the `fuselage_design_ellipses.json` file.

The aircraft is divided into three sections: A cockpit section, followed by a constant section, and the tail section. 
The steps of the shape generation are basically the same for all aircraft sections:

1. Calculate the section length as a percentage of the fuselage length<sup>*</sup>.
2. Proportionally adjust the given reference geometry to match the actual geometry using scaling factors. Therefore, separate scaling factors are calculated for
    - the x-direction (lengthwise),
    - the y-direction (widthwise), and
    - the z-directions (upper and lower heights).
3. Calculate new coordinates as well as ellipses for visualization purposes.

<sup>*</sup> The length of the constant section is determined by subtracting the length of the cockpit and the tail section from the entire fuselage length.

___
<sup>[1]</sup> Prof. Dr.-Ing. Juergen Thorbeck TU Berlin (2006), Script "Flugzeugentwurf I und II" chapter A.<br>
<sup>[2]</sup> M.Sc. Andreas Gobbin (2015), Master Thesis "Numerische Modellierung des Auslegungsprozesses für Passagierkabinen von Verkehrsflugzeugen unter Berücksichtigung der wichtigsten Auslegungsforderungen und Implementierung in MatLab".<br>
<sup>[3]</sup> Egbert Torenbeek, Synthesis of Subsonic Airplane Design (1982), Delft University Press.<br>
<sup>[4]</sup> European Union Aviation Safety Agency (2024),  CS-25 Large Aeroplanes - Amendment 28.