# Getting started
This section will guide you through the necessary steps to get the _fuselage\_design_ module up and running. It contains information on tool requirements and design parameters.

- [Design method selection](#design-method-selection) - How to set the design method?
- [Aircraft exchange file](#aircraft-exchange-file) - Get information on necessary parameters from the _acXML_.
- [Module configuration file](#module-configuration-file) - Dive into fuselage design specific parameters.
- [Additional requirements](#additional-requirements) - Is anything else necessary to get the module running?
- [Next steps](#next-steps) - How to proceed?

!!! note 
    It is assumed that you have the `UNICADO package` installed including the executables and UNICADO libraries.

Generally, we use two files to set or configure modules in UNICADO:

- The aircraft exchange file (or _acXML_) includes
    - data related inputs (e.g., configuration type) and
    - data related outputs (e.g., component design data).
- The module configuration file `fuselage_design_conf.xml` (also _configXML_) includes
    - control settings (e.g., enable/disable generating plots) and
    - program settings (e.g., information on cargo and passenger accommodation).

In the following sections you will find more information on how to configure these files to suit your needs.

## Design method selection {#design-method-selection}
The calculation method is automatically chosen based on the following data from the aircraft exchange and module configuration file:

Parameter            | File          | Example <sup>*</sup>      |
:--------------------|---------------|:--------------------------|
Configuration type   | _acXML_       | tube_and_wing             |
Calculation fidelity | _configXML_   | empirical                 |
Method name          | _configXML_   | fuselage_design_tu_berlin |
Energy carrier type  | _acXML_       | kerosene                  |

<sup>*</sup> This example defines a generic short and medium range tube-and-wing aircraft.

Thus, it must be ensured that this data is available. More information on required data can be found in the following sections.

## Aircraft exchange file requirements {#aircraft-exchange-file}
_fuselage\_design_ can be single executed without the execution of any other module. The only prerequisite is a complete `requirements_and_specifications` block in the aircraft exchange file.

<!-- To single execute the _fuselage\_design_ module, we need an _acXML_ file that already contains the output data from the following tools:
- _module\_name_
- ... -->

The following data should be available in the _acXML_ (2. and 3. are optional):

1. Requirements and specifications
    - Design specification
        - Configuration information
            - Configuration type
            - Fuselage definition: Fuselage type, fuselage pressurization
            - Undercarriage definition: Main gear mounting
            - Wing definition: Wing mounting
        - Transport task
            - Cargo definition: Additional cargo mass, cargo density
            - Passenger class definition: Class distribution
            - Passenger definition: Total number passengers, luggage mass per passenger
            - Multi-passenger deck layout information
        - Energy carrier(s)
        - Propulsion: Positioning of propulsor element(s)
    - Requirements
        - Top level aircraft requirements: Range
2. Analysis
    - Mission: Flight time of design mission
    - Masses, CG, inertia
        - Maximum takeoff mass
        - Most afterward mass: COG position
        - Most forward mass: COG position
3. Component design: Geometrical data of
    - Tank: Additional fuselage length
    - Wing
        - Position
        - Information for wing sections
            - (Name)
            - (Position)
            - Chord origin
            - Chord length
    - Global reference point position

!!! note 
    When the UNICADO workflow is executed the tool is run automatically. In this case, all the required data should be available anyway.

## Module configuration file {#module-configuration-file}
The _configXML_ is structured into two blocks: the control and program settings.

The control settings are standardized in UNICADO and will not be described in detail here. But to get started, you have to change at least

- the `aircraft_exchange_file_name` and `aircraft_exchange_file_directory` to your respective settings,
- the `console_output` at least to `mode_1`, and
- the `plot_output` to false (or define `inkscape_path` and `gnuplot_path`).

!!! note 
    If the tool is executed via the workflow, those settings are set by the workflow settings.

The program settings are structured like this (descriptions can be found in the `fuselage_design_conf.xml`):

```plaintext
Program Settings
|- Configuration (ID="tube_and_wing")
|  |- Fidelity name
|  |- Method name
|  |- Fidelity (ID="empirical")
|  |  |- Fuselage design tu berlin
|  |  |  |- General
|  |  |  |  |- Flight attendant mass
|  |  |  |  |- Flight crew member mass
|  |  |  |  |- Force circular cross section
|  |  |  |  |- High density seat pitch
|  |  |  |  |- Length of flight deck
|  |  |  |  |- Mass technology factors
|  |  |  |  |  |- Fuselage structural mass technology factor
|  |  |  |  |- Name of fuselage
|  |  |  |  |- On board service load
|  |  |  |  |  |- PAX per full size trolley long range
|  |  |  |  |  |- PAX per full size trolley medium range
|  |  |  |  |  |- PAX per full size trolley short range
|  |  |  |  |  |- PAX per full size trolley regional range
|  |  |  |  |- Sizing mode
|  |  |  |  |  |- Setting use existing fuselage
|  |  |  |  |  |  |- Name of existing geometry file
|  |  |  |  |  |  |- Use as starting point
|  |  |  |  |- System bay height above cabin
|  |  |  |- Specific
|  |  |  |  |- Cabin floor offset
|  |  |  |  |- Cargo accommodation
|  |  |  |  |  |- ULD type
|  |  |  |  |  |  |- Container
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Use specific number of LD container
|  |  |  |  |  |  |  |  |- Specific number of LD container
|  |  |  |  |  |  |- Pallet
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Use specific number of cargo pallet
|  |  |  |  |  |  |  |  |- Specific number of cargo pallet
|  |  |  |  |  |- Use internal bulk area
|  |  |  |  |  |  |- Specific internal bulk area
|  |  |  |  |- Dead end cabin arrangement
|  |  |  |  |  |- Dead end cabin arrangement in front
|  |  |  |  |  |- Dead end cabin arrangement in aft
|  |  |  |  |- Exit definition
|  |  |  |  |  |- Auto-select exit types
|  |  |  |  |  |  |- Select specific exit types
|  |  |  |  |  |  |  |- Exit (ID="0")
|  |  |  |  |  |- Plus certification allowed
|  |  |  |  |- Fuselage frame distance
|  |  |  |  |- Passenger accommodation
|  |  |  |  |  |- Divider definition
|  |  |  |  |  |  |- Set divider automatically
|  |  |  |  |  |  |- Use soft divider
|  |  |  |  |  |  |  |- Hard divider thickness
|  |  |  |  |  |  |- Divider width
|  |  |  |  |  |  |  |- Set divider width automatically
|  |  |  |  |  |  |  |- Specific class divider width  
|  |  |  |  |  |- Galley definition
|  |  |  |  |  |  |- Use specific number of full size trolleys
|  |  |  |  |  |  |  |- Specific number of full size trolleys
|  |  |  |  |  |  |- Use specific number of half size trolleys
|  |  |  |  |  |  |  |- Specific number of half size trolleys
|  |  |  |  |  |  |- Use specific number of standard units
|  |  |  |  |  |  |  |- Specific number of standard units
|  |  |  |  |  |- In-flight entertainment
|  |  |  |  |  |  |- Use in-flight entertainment
|  |  |  |  |  |- Passenger classes
|  |  |  |  |  |  |- Class (ID="0")
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Abreast
|  |  |  |  |  |  |  |- Seats
|  |  |  |  |  |  |  |  |- Seat on left side
|  |  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |  |- Seat pitch
|  |  |  |  |  |  |  |  |- Seat on right side
|  |  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |  |- Seat pitch
|  |  |  |  |  |  |  |  |- Seat in the center
|  |  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |  |- Seat pitch
|  |  |  |  |  |  |  |- Seat space
|  |  |  |  |  |  |  |- Lavatories
|  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |- PAX per lavatory
|  |  |  |  |  |  |  |  |- Use specific number of class lavatories
|  |  |  |  |  |  |  |  |  |- Specific number of class lavatories
|  |  |  |  |  |  |  |- Wardrobe
|  |  |  |  |  |  |  |  |- Use wardrobe for passenger class
|  |  |  |  |- Passenger aisle
|  |  |  |  |  |- Width
|  |  |  |  |  |- Standing height
|  |  |  |  |  |- Standing height seat row
```

## Additional requirements {#additional-requirements}

### Fuselage design library
The fuselage design library contains files that are necessary to generate a valid fuselage and cabin design.

#### Reference ellipses
The reference aircraft ellipses are used to create the outer shape of the aircraft.
There are reference ellipses for the following sections:

- Cockpit section
- Constant section
- Tail sections

Furthermore, there is data for the reference diameter and information on scaling factors.

#### Accommodation definitions
The `accommodation_definitions.xml` file contains information on the passenger and cargo definition for the following categories:

- Cabin interior such as seats, galleys, trolleys, lavatories, and wardrobes as well as respective masses
- Cargo accommodation such as containers or pallets
- Emergency slides
- Safety equipment masses

#### Fuselage design certification requirements
The `fuselage_design_cs_requirements.xml` file contains necessary design requirements regarding the following topics:

- Emergency exit definition and positioning (according to CS-25.807ff)
- Cabin design specifications such as the aisle dimensions and cross aisle overlaps (according to CS-25.807ff)
- Container arrangement
- Maximum number of PAX per flight attendant
- Maximum crew duty time

!!! note 
    Please do not change any values that are set in accordance with the CS-25. Otherwise compliance of the design with the certification requirements cannot be guaranteed.

## Next steps {#next-steps}
The next step is to [run the _fuselage\_design_ module](run_your_first_design.md).