# Design your first fuselage
Let's dive into the fun part and design a fuselage!

## Tool single execution
The tool can be executed from the console directly if all paths are set. The following will happen:

- [Console output](#console-output)
- [Generation of reports and plots](#reporting)
- [Writing output to aircraft exchange file](#acxml)
- [Writing geometry data to .json file](#geometry-data)

Some of the above mentioned steps did not work? Check out the [troubleshooting](#troubleshooting) section for advices.
Also, if you need some additional information on the underlying methodology, check out the page on the [fuselage design method](design_method.md).

So, feel free to open the terminal and run `fuselage_design.exe` to see what happens...

### Console output {#console-output}
Firstly, you see output in the console window. Let's go through it step by step...

```
2024-11-11 17:34:30,743 - PRINT - Fuselage design started...
2024-11-11 17:34:30,803 - PRINT - Import of fuselage design cs requirements xml-file and accommodation definition xml-file successfully.
2024-11-11 17:34:30,805 - PRINT - Current iteration of fuselage design is: 1
```
To this point, the module started, found the required XML files and printed the iteration counter.

```
2024-11-11 17:34:30,812 - PRINT - Total length of fuselage is: 37.0553 meter.
2024-11-11 17:34:30,812 - PRINT - Total width of fuselage is: 3.968 meter.
2024-11-11 17:34:30,813 - PRINT - Total height of fuselage is: 4.1425 meter.
```
Afterwards, the fuselage design starts and prints values for the whole fuselage.

```
2024-11-11 17:34:30,813 - PRINT - Total length of cabin is: 26.6847 meter.
2024-11-11 17:34:30,813 - PRINT - Total width of cabin is: 3.6932 meter.
2024-11-11 17:34:30,813 - PRINT - Wall thickness of cabin is: 0.1374 meter.
2024-11-11 17:34:30,813 - PRINT - Floor thickness of cabin is: 0.2062 meter.
2024-11-11 17:34:30,814 - PRINT - Fuselage design successful after 1 iterations!
```
The tool continues with the print of cabin parameters and the information that the fuselage design was successful after one iteration.

```
2024-11-11 17:34:32,356 - PRINT - Plots for fuselage design are successfully generated and saved.
2024-11-11 17:34:32,356 - PRINT - Moin! This is the "method_html_report" function from the fuselage_design tool speaking... [Imagine fancy reports are generated here (you can find me in the "methodhtmlreport.py" file).]
2024-11-11 17:34:32,359 - PRINT - Method-specific data are written to 'fuselage_design_results.xml'...
2024-11-11 17:34:32,371 - PRINT - Moin! This is the "method_tex_output" function from the fuselage_design tool speaking... [Imagine fancy reports are generated here (you can find me in the "methodtexoutput.py" file).]
2024-11-11 17:34:32,372 - PRINT - Fuselage design finished.
```
Finally, you receive information about the reports and plots created (depending on your settings) and the tool is successfully completed.

### Reporting {#reporting}
In the following, a short overview is given on the generated reports:

- A `fuselage_design.log` file is written within the directory of the executable
- Depending on your settings, the following output is generated and saved in the `reporting` folder, located in the directory of the aircraft exchange file:
    - an HTML report in the `report_html` folder
    - a TeX report in the `report_tex` folder (not implemented yet)
    - an XML file with additional output data in the `report_xml` folder
    - plots in the `plots` folder

### Write data to the aircraft exchange file {#acxml}
!!! note 
    The _acXML_ is an exchange file - we agreed on that only data will be saved as output that is needed by another tool!

Results are saved in the aircraft exchange file at the `/aircraft_exchange_file/component_design/fuselage` node. The following information is written to the _acXML_:
```plaintext
Aircraft exchange file
|- Component design
|  |- Fuselage
|  |  |- Position*
|  |  |- Mass properties**
|  |  |- Specific
|  |  |  |- Geometry
|  |  |  |  |- Fuselage (ID="0")
|  |  |  |  |  |- Name
|  |  |  |  |  |- Position*
|  |  |  |  |  |- Direction*
|  |  |  |  |  |- Mass properties**
|  |  |  |  |  |- Sections
|  |  |  |  |  |  |- Section (ID="0")
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Section shape
|  |  |  |  |  |  |  |- Origin*
|  |  |  |  |  |  |  |- Upper height
|  |  |  |  |  |  |  |- Lower height
|  |  |  |  |  |  |  |- Width
|  |  |  |  |  |- Number of required cabin crew
|  |  |  |  |  |- Number of required flight crew
|  |  |  |  |  |- Mass breakdown
|  |  |  |  |  |  |- Fuselage structure
|  |  |  |  |  |  |  |- Component mass (ID="0")
|  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |- Mass
|  |  |  |  |  |  |- Fuselage furnishing
|  |  |  |  |  |  |  |- Component mass (ID="0")
|  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |- Mass
|  |  |  |  |  |  |- Fuselage operator items
|  |  |  |  |  |  |  |- Component mass (ID="0")
|  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |- Mass
|  |  |  |  |  |- Fuselage accommodation
|  |  |  |  |  |  |- Position*
|  |  |  |  |  |  |- Mass properties
|  |  |  |  |  |  |- Payload tube (ID="0")
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Payload tube reference points
|  |  |  |  |  |  |  |  |- Front reference points
|  |  |  |  |  |  |  |  |  |- x
|  |  |  |  |  |  |  |  |  |- y
|  |  |  |  |  |  |  |  |  |- z
|  |  |  |  |  |  |  |  |  |- Upper z
|  |  |  |  |  |  |  |  |  |- Lower z
|  |  |  |  |  |  |  |  |- Aft reference points
|  |  |  |  |  |  |  |  |  |- (see 'Front reference points')
|  |  |  |  |  |  |  |- Payload tube wall reference points
|  |  |  |  |  |  |  |  |- Front reference points
|  |  |  |  |  |  |  |  |  |- x
|  |  |  |  |  |  |  |  |  |- Left y
|  |  |  |  |  |  |  |  |  |- Right y
|  |  |  |  |  |  |  |  |  |- z
|  |  |  |  |  |  |  |  |- Aft reference points
|  |  |  |  |  |  |  |  |  |- (see 'Front reference points')
|  |  |  |  |  |  |  |- Payload tube structural wall thickness
|  |  |  |  |  |  |  |- Payload tube water volume
|  |  |  |  |  |  |  |- Payload decks
|  |  |  |  |  |  |  |  |- Payload deck (ID="0")
|  |  |  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |  |  |- Position*
|  |  |  |  |  |  |  |  |  |- Payload deck structural floor thickness
|  |  |  |  |  |  |  |  |  |- Payload deck water volume
|  |  |  |  |  |  |  |  |  |- Payload deck length
|  |  |  |  |  |  |  |  |  |- Payload deck required galley power 
```

<sup>*</sup> Node has been shortened. It contains the following sub-nodes: x, y, z

<sup>*</sup> Node has been shortened. It contains sub-nodes with information on the mass, inertia, and center of gravity.

### Write geometry data to .json file {#geometry-data}
The calculated geometry data is written to the `fuselage_design_ellipses.json` file and can then be used if the `use_existing_geometry` flag is set to `true`.

## Troubleshooting {#troubleshooting}
- The tool does not run properly? *Make sure you have all the paths set up correctly and the specified elements exist.*
